@@ -580,6 +580,16 @@ fn warn_on_missing_python_source() {
     handle_result(errors::warn_on_missing_python_source())
 }
 
+#[test]
+fn pypi_compatibility_unsupported_target() {
+    handle_result(errors::pypi_compatibility_unsupported_target())
+}
+
+#[test]
+fn pypi_compatibility_mixed_tags() {
+    handle_result(errors::pypi_compatibility_mixed_tags())
+}
+
 #[test]
 #[cfg_attr(not(target_os = "linux"), ignore)]
 fn musl() {
@@ -640,7 +650,7 @@ fn workspace_members_non_local_dep_sdist() {
         license = "MIT"
 
         [dependencies]
-        pyo3 = { version = "0.24.0", features = [
+        pyo3 = { version = "0.25.0", features = [
             "abi3-py37",
             "extension-module",
             "generate-import-lib",
@@ -709,7 +719,7 @@ fn lib_with_target_path_dep_sdist() {
         crate-type = ["cdylib"]
 
         [dependencies]
-        pyo3 = { version = "0.24.0", features = ["extension-module"] }
+        pyo3 = { version = "0.25.0", features = ["extension-module"] }
 
         [target.'cfg(not(target_endian = "all-over-the-place"))'.dependencies]
         some_path_dep = { path = "../some_path_dep" }
